@@ -3,13 +3,13 @@ makeContrasts <- function(factors,
                           quanti, 
                           posquanti)
 {
-  if(quali){#S qualitativos
+  if(quali){#only quantitatives
     contrast <- lapply(factors,
                        function(x)diag(length(x))) 
-  } else if(quanti){#S quantitativos
+  } else if(quanti){#only quantitatives
     contrast <- lapply(factors,
                        function(x)contr.poly(length(x)))                            
-  } else {#hbrido
+  } else {#hybrido
     contrast <- lapply(factors,
                        function(x)diag(length(x)))
     contrast[posquanti] <- lapply(factors[posquanti],
